# SMDP-BCQ

This repository contains an installable version of the SMDP-BCQ model.

## Installation

The model has been tested using Python 3.9 and PyTorch 1.9. To install using Pip:

    $ python3 -m pip install pytorch_smdbcq

## Demo

    $ python3 -m smdbcq --demo

## See also

Our application of this model to [warfarin dosing](https://github.com/hamilton-health-sciences/warfarin) (*under review*) and [experiments](https://github.com/mary-wu/smdp) validating its estimation (CHIL 2022).
